@@ -15,7 +15,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #ifndef LIBDPKG_DEB_VERSION_H
@@ -40,12 +40,19 @@ struct deb_version {
 };
 
 /**
- * Initializer for a deb_version.
+ * Constant initializer for a deb_version.
  */
 #define DEB_VERSION(X, Y) \
-	(struct deb_version){ .major = (X), .minor = (Y) }
+	{ .major = (X), .minor = (Y) }
 
-const char *deb_version_parse(struct deb_version *version, const char *str);
+/**
+ * Compound literal for a deb_version.
+ */
+#define DEB_VERSION_OBJECT(X, Y) \
+	(struct deb_version)DEB_VERSION(X, Y)
+
+const char *
+deb_version_parse(struct deb_version *version, const char *str);
 
 /** @} */
 
