@@ -22,6 +22,7 @@
 #ifndef LIBDPKG_REPORT_H
 #define LIBDPKG_REPORT_H
 
+#include <stdbool.h>
 #include <stdarg.h>
 #include <stdio.h>
 
@@ -35,14 +36,40 @@ DPKG_BEGIN_DECLS
  * @{
  */
 
-void dpkg_set_report_piped_mode(int mode);
-void dpkg_set_report_buffer(FILE *fp);
+void
+dpkg_set_report_piped_mode(int mode);
+void
+dpkg_set_report_buffer(FILE *fp);
 
-int warning_get_count(void);
-void warningv(const char *fmt, va_list args) DPKG_ATTR_VPRINTF(1);
-void warning(const char *fmt, ...) DPKG_ATTR_PRINTF(1);
+typedef void dpkg_warning_printer_func(const char *msg, void *data);
 
-void notice(const char *fmt, ...) DPKG_ATTR_PRINTF(1);
+void
+dpkg_warning_printer(const char *msg, void *data);
+void
+dpkg_set_warning_printer(dpkg_warning_printer_func *printer, void *data);
+
+int
+warning_get_count(void);
+void
+warningv(const char *fmt, va_list args)
+	DPKG_ATTR_VPRINTF(1);
+void
+warning(const char *fmt, ...)
+	DPKG_ATTR_PRINTF(1);
+
+void
+notice(const char *fmt, ...)
+	DPKG_ATTR_PRINTF(1);
+
+void
+info(const char *fmt, ...)
+	DPKG_ATTR_PRINTF(1);
+
+void
+dpkg_set_hints_enable(bool enable);
+void
+hint(const char *fmt, ...)
+	DPKG_ATTR_PRINTF(1);
 
 /** @} */
 
