@@ -11,17 +11,30 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <https://www.gnu.org/licenses/>.
 
-package Dpkg::ErrorHandling;
+=encoding utf8
 
-use strict;
-use warnings;
+=head1 NAME
+
+Dpkg::ErrorHandling - handle error conditions
+
+=head1 DESCRIPTION
+
+This module provides functions to handle all reporting and error handling.
+
+B<Note>: This is a private module, its API can change at any time.
+
+=cut
+
+package Dpkg::ErrorHandling 0.02;
+
+use v5.36;
 
-our $VERSION = '0.02';
 our @EXPORT_OK = qw(
     REPORT_PROGNAME
     REPORT_COMMAND
     REPORT_STATUS
     REPORT_DEBUG
+    REPORT_HINT
     REPORT_INFO
     REPORT_NOTICE
     REPORT_WARN
@@ -33,6 +46,7 @@ our @EXPORT_OK = qw(
 our @EXPORT = qw(
     report_options
     debug
+    hint
     info
     notice
     warning
@@ -45,19 +59,19 @@ our @EXPORT = qw(
 );
 
 use Exporter qw(import);
-use Term::ANSIColor;
 
 use Dpkg ();
 use Dpkg::Gettext;
 
 my $quiet_warnings = 0;
+my $show_hints = 1;
 my $debug_level = 0;
 my $info_fh = \*STDOUT;
-my $use_color = 0;
 
 sub setup_color
 {
     my $mode = $ENV{'DPKG_COLORS'} // 'auto';
+    my $use_color;
 
     if ($mode eq 'auto') {
         ## no critic (InputOutput::ProhibitInteractiveTest)
@@ -67,9 +81,9 @@ sub setup_color
     } else {
         $use_color = 0;
     }
-}
 
-setup_color();
+    require Term::ANSIColor if $use_color;
+}
 
 use constant {
     REPORT_PROGNAME => 1,
@@ -80,6 +94,7 @@ use constant {
     REPORT_WARN => 6,
     REPORT_ERROR => 7,
     REPORT_DEBUG => 8,
+    REPORT_HINT => 9,
 };
 
 my %report_mode = (
@@ -101,6 +116,10 @@ my %report_mode = (
         # and all debug messages are untranslated anyway.
         name => 'debug',
     },
+    REPORT_HINT() => {
+        color => 'bold blue',
+        name => g_('hint'),
+    },
     REPORT_INFO() => {
         color => 'green',
         name => g_('info'),
@@ -121,16 +140,19 @@ my %report_mode = (
 
 sub report_options
 {
-    my (%options) = @_;
+    my (%opts) = @_;
 
-    if (exists $options{quiet_warnings}) {
-        $quiet_warnings = $options{quiet_warnings};
+    if (exists $opts{quiet_warnings}) {
+        $quiet_warnings = $opts{quiet_warnings};
     }
-    if (exists $options{debug_level}) {
-        $debug_level = $options{debug_level};
+    if (exists $opts{show_hints}) {
+        $show_hints = $opts{show_hints};
     }
-    if (exists $options{info_fh}) {
-        $info_fh = $options{info_fh};
+    if (exists $opts{debug_level}) {
+        $debug_level = $opts{debug_level};
+    }
+    if (exists $opts{info_fh}) {
+        $info_fh = $opts{info_fh};
     }
 }
 
@@ -152,8 +174,10 @@ sub report_pretty
 {
     my ($msg, $color) = @_;
 
+    state $use_color = setup_color();
+
     if ($use_color) {
-        return colored($msg, $color);
+        return Term::ANSIColor::colored($msg, $color);
     } else {
         return $msg;
     }
@@ -171,11 +195,11 @@ sub _typename_prefix
     return report_pretty(report_name($type), report_color($type));
 }
 
-sub report(@)
+sub report
 {
-    my ($type, $msg) = (shift, shift);
+    my ($type, $msg, @args) = @_;
 
-    $msg = sprintf($msg, @_) if (@_);
+    $msg = sprintf $msg, @args if @args;
 
     my $progname = _progname_prefix();
     my $typename = _typename_prefix($type);
@@ -185,39 +209,60 @@ sub report(@)
 
 sub debug
 {
-    my $level = shift;
-    print report(REPORT_DEBUG, @_) if $level <= $debug_level;
+    my ($level, @args) = @_;
+
+    print report(REPORT_DEBUG, @args) if $level <= $debug_level;
 }
 
-sub info($;@)
+sub hint
 {
-    print { $info_fh } report(REPORT_INFO, @_) if not $quiet_warnings;
+    my @args = @_;
+
+    return if not $show_hints;
+
+    print report(REPORT_HINT, @args) if not $quiet_warnings;
+}
+
+sub info
+{
+    my @args = @_;
+
+    print { $info_fh } report(REPORT_INFO, @args) if not $quiet_warnings;
 }
 
 sub notice
 {
-    warn report(REPORT_NOTICE, @_) if not $quiet_warnings;
+    my @args = @_;
+
+    warn report(REPORT_NOTICE, @args) if not $quiet_warnings;
 }
 
-sub warning($;@)
+sub warning
 {
-    warn report(REPORT_WARN, @_) if not $quiet_warnings;
+    my @args = @_;
+
+    warn report(REPORT_WARN, @args) if not $quiet_warnings;
 }
 
-sub syserr($;@)
+sub syserr
 {
-    my $msg = shift;
-    die report(REPORT_ERROR, "$msg: $!", @_);
+    my ($msg, @args) = @_;
+
+    die report(REPORT_ERROR, "$msg: $!", @args);
 }
 
-sub error($;@)
+sub error
 {
-    die report(REPORT_ERROR, @_);
+    my @args = @_;
+
+    die report(REPORT_ERROR, @args);
 }
 
-sub errormsg($;@)
+sub errormsg
 {
-    print { *STDERR } report(REPORT_ERROR, @_);
+    my @args = @_;
+
+    print { *STDERR } report(REPORT_ERROR, @args);
 }
 
 sub printcmd
@@ -227,33 +272,43 @@ sub printcmd
     print { *STDERR } report_pretty(" @cmd\n", report_color(REPORT_COMMAND));
 }
 
-sub subprocerr(@)
+sub subprocerr
 {
-    my ($p) = (shift);
+    my ($p, @args) = @_;
 
-    $p = sprintf($p, @_) if (@_);
+    $p = sprintf $p, @args if @args;
 
     require POSIX;
 
     if (POSIX::WIFEXITED($?)) {
-	error(g_('%s gave error exit status %s'), $p, POSIX::WEXITSTATUS($?));
+        my $ret = POSIX::WEXITSTATUS($?);
+        error(g_('%s subprocess failed with exit status %d'), $p, $ret);
     } elsif (POSIX::WIFSIGNALED($?)) {
-	error(g_('%s died from signal %s'), $p, POSIX::WTERMSIG($?));
+        my $sig = POSIX::WTERMSIG($?);
+        error(g_('%s subprocess was killed by signal %d'), $p, $sig);
     } else {
-	error(g_('%s failed with unknown exit code %d'), $p, $?);
+        error(g_('%s subprocess failed with unknown status code %d'), $p, $?);
     }
 }
 
-my $printforhelp = g_('Use --help for program usage information.');
-
-sub usageerr(@)
+sub usageerr
 {
-    my ($msg) = (shift);
+    my ($msg, @args) = @_;
 
-    $msg = sprintf($msg, @_) if (@_);
+    state $printforhelp = g_('Use --help for program usage information.');
+
+    $msg = sprintf $msg, @args if @args;
     warn report(REPORT_ERROR, $msg);
     warn "\n$printforhelp\n";
     exit(2);
 }
 
+=head1 CHANGES
+
+=head2 Version 0.xx
+
+This is a private module.
+
+=cut
+
 1;
